==> search-ui-elasticsearch-connector-1.13.0.tgz: package/lib/esm/handlers/autocomplete/index.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import Searchkit, { CompletionSuggester, HitsSuggestor, PrefixQuery } from "@searchkit/sdk";
import { fieldResponseMapper } from "../common";
import { getQueryFields, getResultFields } from "../search/Configuration";
export default function handleRequest(configuration) {
    return __awaiter(this, void 0, void 0, function* () {
        const { state, queryConfig, host, index, connectionOptions } = configuration;
        const { apiKey } = connectionOptions || {};
        const suggestionConfigurations = [];
        if (queryConfig.results) {
            const { hitFields, highlightFields } = getResultFields(queryConfig.results.result_fields);
            const queryFields = getQueryFields(queryConfig.results.search_fields);
            suggestionConfigurations.push(new HitsSuggestor({
                identifier: "hits-suggestions",
                hits: {
                    fields: hitFields,
                    highlightedFields: highlightFields
                },
                query: new PrefixQuery({ fields: queryFields }),
                size: queryConfig.results.resultsPerPage || 5
            }));
        }
        if (queryConfig.suggestions && queryConfig.suggestions.types) {
            const configs = Object.keys(queryConfig.suggestions.types).map((type) => {
                const { fields } = queryConfig.suggestions.types[type];
                return new CompletionSuggester({
                    identifier: type,
                    field: fields[0],
                    size: queryConfig.suggestions.size || 5
                });
            });
            suggestionConfigurations.push(...configs);
        }
        const searchkitConfig = {
            host,
            index,
            connectionOptions: {
                apiKey
            },
            suggestions: suggestionConfigurations
        };
        const response = yield Searchkit(searchkitConfig).executeSuggestions(state.searchTerm);
        const results = response.reduce((sum, suggestion) => {
            if (suggestion.identifier === "hits-suggestions") {
                return Object.assign(Object.assign({}, sum), { autocompletedResults: suggestion.hits.map(fieldResponseMapper) });
            }
            else {
                return Object.assign(Object.assign({}, sum), { autocompletedSuggestions: Object.assign(Object.assign({}, sum.autocompletedSuggestions), { [suggestion.identifier]: suggestion.suggestions.map((suggestion) => {
                            return {
                                suggestion: suggestion
                            };
                        }) }) });
            }
        }, {
            autocompletedSuggestions: {}
        });
        return results;
    });
}

==> search-ui-elasticsearch-connector-1.15.0.tgz: package/lib/esm/handlers/autocomplete/index.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import Searchkit, { CompletionSuggester, HitsSuggestor, PrefixQuery } from "@searchkit/sdk";
import { fieldResponseMapper } from "../common";
import { getQueryFields, getResultFields } from "../search/Configuration";
export default function handleRequest(configuration) {
    return __awaiter(this, void 0, void 0, function* () {
        const { state, queryConfig, host, cloud, index, connectionOptions } = configuration;
        const { apiKey } = connectionOptions || {};
        const suggestionConfigurations = [];
        if (queryConfig.results) {
            const { hitFields, highlightFields } = getResultFields(queryConfig.results.result_fields);
            const queryFields = getQueryFields(queryConfig.results.search_fields);
            suggestionConfigurations.push(new HitsSuggestor({
                identifier: "hits-suggestions",
                hits: {
                    fields: hitFields,
                    highlightedFields: highlightFields
                },
                query: new PrefixQuery({ fields: queryFields }),
                size: queryConfig.results.resultsPerPage || 5
            }));
        }
        if (queryConfig.suggestions && queryConfig.suggestions.types) {
            const configs = Object.keys(queryConfig.suggestions.types).map((type) => {
                const { fields } = queryConfig.suggestions.types[type];
                return new CompletionSuggester({
                    identifier: type,
                    field: fields[0],
                    size: queryConfig.suggestions.size || 5
                });
            });
            suggestionConfigurations.push(...configs);
        }
        const searchkitConfig = {
            host,
            cloud,
            index,
            connectionOptions: {
                apiKey
            },
            suggestions: suggestionConfigurations
        };
        const response = yield Searchkit(searchkitConfig).executeSuggestions(state.searchTerm);
        const results = response.reduce((sum, suggestion) => {
            if (suggestion.identifier === "hits-suggestions") {
                return Object.assign(Object.assign({}, sum), { autocompletedResults: suggestion.hits.map(fieldResponseMapper) });
            }
            else {
                return Object.assign(Object.assign({}, sum), { autocompletedSuggestions: Object.assign(Object.assign({}, sum.autocompletedSuggestions), { [suggestion.identifier]: suggestion.suggestions.map((suggestion) => {
                            return {
                                suggestion: suggestion
                            };
                        }) }) });
            }
        }, {
            autocompletedSuggestions: {}
        });
        return results;
    });
}
